@@ -777,20 +777,31 @@ def _column_stats_callback(task_response, payload):
     return column_stats
 
 def _insights_callback(task_response, payload):
-    table = []
-    # for network insights
-    if "InsightsReport" in task_response:
-        for insight in task_response["InsightsReport"]:
-            table.append([insight["Title"], insight["Story"]])
-        # TODO: Aakash, I don't think this works. Is vip.insights() supposed to show anything? It doesn't
-        display(HTML(tabulate.tabulate(table, headers=["Topic", "Insight"], tablefmt='html')))
+    network_insights_table = []
+    standard_insights_table = []
 
-    # for standard insights
-    if "NonNetworkInsights" in task_response:
-        for insight in task_response["NonNetworkInsights"]:
-            table.append([insight["Key Insight"]])
-        
-        display(HTML(tabulate.tabulate(table, headers=["Insight"], tablefmt='html')))
+    insight_type = "standard"
+    insights_df = None
+
+    if "InsightType" in task_response:
+        insight_type = task_response["InsightType"]
+
+    # for network insights
+    if insight_type.lower() == "network":
+        if "InsightsReport" in task_response:
+            for insight in task_response["InsightsReport"]:
+                network_insights_table.append([insight["Title"], insight["Story"]])
+            # TODO: Aakash, I don't think this works. Is vip.insights() supposed to show anything? It doesn't
+            display(HTML(tabulate.tabulate(network_insights_table, headers=["Topic", "Insight"], tablefmt='html')))
+            insights_df = pd.DataFrame(network_insights_table)
+    elif insight_type.lower() == "standard":
+        # for standard insights
+        if "NonNetworkInsights" in task_response:
+            for insight in task_response["NonNetworkInsights"]:
+                standard_insights_table.append([insight["Key Insight"]])
+            
+            display(HTML(tabulate.tabulate(standard_insights_table, headers=["Insight"], tablefmt='html')))
+            insights_df = pd.DataFrame(standard_insights_table)
 
     notes_message = ""
     if "Note" in task_response:
@@ -799,6 +810,8 @@ def _insights_callback(task_response, payload):
 
     print(notes_message)
 
+    return insights_df
+
 def _explainable_ai_callback(task_response, payload):
     table = []
     if "ExplainableAIReport" in task_response:
@@ -813,6 +826,8 @@ def _explainable_ai_callback(task_response, payload):
 
     print(notes_message)
 
+    return pd.DataFrame(table)
+
 def _dataset_callback(task_response, payload):
     if "DataSetName" in task_response:
         print("Data set loaded with name: '%s'" % task_response["DataSetName"])
